import React, { useEffect } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import SessionListComponent from "./SessionListComponent";
import { loadServerSessions, loadSessionForwards } from "../actionCreators";

const SessionContainer = ({ actions, sessions, forwards }) => {
  useEffect(() => {
    actions.loadServerSessions();
  }, []);

  const handleToggle = (sessionId) => (_, expanded) => {
    if (expanded) actions.loadSessionForwards(sessionId);
  };

  return (
    <SessionListComponent
      sessions={sessions}
      handleToggle={handleToggle}
      forwards={forwards}
    />
  );
};

SessionContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  sessions: PropTypes.array.isRequired,
  forwards: PropTypes.object.isRequired
};

function mapStateToProps(state) {
  return {
    sessions: state.sessions,
    forwards: state.forwards
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { loadServerSessions, loadSessionForwards },
      dispatch
    )
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(SessionContainer);
